@@ -62,24 +62,24 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
             'api_keys': ApiKeyList,
         }
 
-    def _resolve_group(self, group_object_or_href_or_name):
-        """Given a Group object or href or name, return a functional Group
-        object.
+    def _resolve_group(self, resolvable):
+        """Given a Group object or href, name, or search query, return a
+        functional Group object.
 
         This helper method allows us to easily accept Group arguments in
         multiple ways.
 
-        :param group_object_or_href_or_name: This could be any one of the
-            following:
+        :param resolvable: This could be any one of the following:
 
             - A :class:`stormpath.resources.group.Group` object, that already
               exists in Stormpath.
             - A Group href, ex:
               'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
             - A Group name, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
 
         :raises:
-            - ValueError if an invalid href or name is specified.
+            - ValueError if an invalid href, name, or search query is specified.
             - TypeError if a non-Group object is specified.
 
         :rtype: obj
@@ -93,21 +93,16 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
         from .group import Group
 
         # If this is a Group object already, we have no work to do!
-        if isinstance(group_object_or_href_or_name, Group):
-            return group_object_or_href_or_name
-
-        # We now know this isn't a Group object.
-        href_or_name = group_object_or_href_or_name
+        if isinstance(resolvable, Group):
+            return resolvable
 
         # Check to see whether or not this is a string.
-        if isinstance(group_object_or_href_or_name, string_types):
+        if isinstance(resolvable, string_types):
 
             # If this Group is an href, we'll just use that.
-            if href_or_name.startswith(self._client.BASE_URL):
-                href = href_or_name
-
+            if resolvable.startswith(self._client.BASE_URL):
                 try:
-                    group = self.directory.groups.get(href)
+                    group = self.directory.groups.get(resolvable)
 
                     # We're accessing group.name here to force evaluation of
                     # this Group -- this allows us to check and see whether or
@@ -121,56 +116,97 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
             # Otherwise, we'll assume this is a Group name, and try to query
             # it.
             else:
-                name = href_or_name
-                groups = self.directory.groups.query(name=name)
+                groups = self.directory.groups.query(name=resolvable)
 
                 for g in groups:
-                    if g.name == name:
+                    if g.name == resolvable:
                         return g
 
                 raise ValueError('Invalid Group name specified.')
 
+        # Check to see whether or not this is a dictionary -- if it is, this
+        # means the user is specifying their own search criteria.
+        if isinstance(resolvable, dict):
+            try:
+                for group in self.directory.groups.search(resolvable):
+                    return group
+
+                raise StormpathError
+            except StormpathError:
+                raise ValueError('Invalid search criteria specified.')
+
         # If this is not a string instance, something horrible was given to us,
         # so bail.
-        raise TypeError('Unsupported type. Group object, href, or name required.')
+        raise TypeError('Unsupported type. Group object, href, name, or search query required.')
 
-    def add_group(self, group_object_or_href_or_name):
+    def add_group(self, resolvable):
         """Associate a Group with this Account.
 
         This creates a
         :class:`stormpath.resources.group_membership.GroupMembership` resource
         on the backend.
 
-        :param group_object_or_href_or_name: This could be any one of the
-            following:
+        :param resolvable: This could be any one of the following:
 
             - A :class:`stormpath.resources.group.Group` object.
             - A Group href, ex:
                 'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
             - A Group name, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
 
         .. note::
             Passing in a :class:`stormpath.resources.group.Group` object will
             always be the quickest way to add a Group, as it doesn't require
             any additional API calls.
         """
-        group = self._resolve_group(group_object_or_href_or_name)
+        group = self._resolve_group(resolvable)
         return self._client.group_memberships.create({
             'account': self,
             'group': group,
         })
 
-    def has_group(self, group_object_or_href_or_name):
+    def add_groups(self, resolvables):
+        """Associate a list of Groups with this Account.
+
+        :param resolvables: A list of either:
+
+            - :class:`stormpath.resources.group.Group` objects.
+            - Group hrefs, ex:
+                'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
+            - Group names, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
+
+                This could look something like:
+
+                [
+                    group,
+                    'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3',
+                    'admins',
+                    {'name': '*_admins'},
+                ]
+
+        .. note::
+            Passing in a :class:`stormpath.resources.group.Group` object will
+            always be the quickest way to add a Group, as it doesn't require
+            any additional API calls.
+        """
+        for g in [self._resolve_group(group) for group in resolvables]:
+            self._client.group_memberships.create({
+                'account': self,
+                'group': g,
+            })
+
+    def has_group(self, resolvable):
         """Check to see whether or not this Account is a member of the
         specified Group.
 
-        :param group_object_or_href_or_name: This could be any one of the
-            following:
+        :param resolvable: This could be any one of the following:
 
             - A :class:`stormpath.resources.group.Group` object.
             - A Group href, ex:
                 'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
             - A Group name, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
 
         .. note::
             Passing in a :class:`stormpath.resources.group.Group` object will
@@ -180,7 +216,7 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
         :returns: True if the Account is a member of the Group, False
             otherwise.
         """
-        group = self._resolve_group(group_object_or_href_or_name)
+        group = self._resolve_group(resolvable)
 
         for g in self.groups.query(name=group.name):
             if g.name == group.name:
@@ -188,25 +224,25 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
 
         return False
 
-    def has_groups(self, group_objects_or_hrefs_or_names, all=True):
+    def has_groups(self, resolvables, all=True):
         """Check to see whether or not this Account is a member of a list of
         Groups.
 
-        :param group_objects_or_hrefs_or_names: A list of either:
+        :param resolvables: A list of either:
 
             - :class:`stormpath.resources.group.Group` objects.
             - Group hrefs, ex:
                 'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
             - Group names, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
 
                 This could look something like:
 
                 [
                     group,
-
                     'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3',
-
                     'admins',
+                    {'name': '*_admins'},
                 ]
 
         :param all: A boolean (default: True) which controls how Group
@@ -219,15 +255,14 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
         """
         total_checks = 0
 
-        groups = group_objects_or_hrefs_or_names
-        for group in groups:
+        for group in resolvables:
             if self.has_group(group):
                 total_checks += 1
 
                 if not all:
                     return True
 
-        return True if all and total_checks == len(groups) else False
+        return True if all and total_checks == len(resolvables) else False
 
     def is_unverified(self):
         """Check if Account is unverified.
@@ -240,16 +275,16 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
         """
         return self.get_status() == self.STATUS_UNVERIFIED
 
-    def remove_group(self, group_object_or_href_or_name):
+    def remove_group(self, resolvable):
         """Remove this Account from the specified Group.
 
-        :param group_object_or_href_or_name: This could be any one of the
-            following:
+        :param resolvable: This could be any one of the following:
 
             - A :class:`stormpath.resources.group.Group` object.
             - A Group href, ex:
                 'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
             - A Group name, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
 
         :raises: :class:`stormpath.error.StormpathError` if the Group specified
             does not contain this Account.
@@ -259,7 +294,7 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
             always be the quickest way to check a Group's membership, since it
             doesn't require any additional API calls.
         """
-        group = self._resolve_group(group_object_or_href_or_name)
+        group = self._resolve_group(resolvable)
 
         for membership in self.group_memberships:
             if membership.group.href == group.href:
@@ -270,6 +305,43 @@ class Account(Resource, AutoSaveMixin, DictMixin, DeleteMixin, StatusMixin):
             'developerMessage': 'This user is not part of Group %s.' % group.name,
         })
 
+    def remove_groups(self, resolvables):
+        """Remove this Account from the specified Groups.
+
+        :param resolvables: A list of either:
+
+            - A :class:`stormpath.resources.group.Group` object.
+            - A Group href, ex:
+                'https://api.stormpath.com/v1/groups/3wzkqr03K8WxRp8NQuYSs3'
+            - A Group name, ex: 'admins'.
+            - A search query, ex: {'name': '*_admins'}.
+
+        :raises: :class:`stormpath.error.StormpathError` if the Groups
+            specified do not contain this Account.
+
+        .. note::
+            Passing in a :class:`stormpath.resources.group.Group` object will
+            always be the quickest way to check a Group's membership, since it
+            doesn't require any additional API calls.
+        """
+        memberships = [membership for membership in self.group_memberships]
+        for g in [self._resolve_group(group) for group in resolvables]:
+            done = False
+            for membership in memberships:
+                if membership.group.href == g.href:
+                    membership.delete()
+                    done = True
+
+            if not done:
+                raise StormpathError({
+                    'developerMessage': 'This user is not part of Group %s.' % g.name,
+                })
+
+
+# Proxy methods for convenience.
+Account.in_group = Account.has_group
+Account.in_groups = Account.has_groups
+
 
 class AccountList(CollectionResource):
     """Stormpath Account resource list."""
